ImmCapAccessRequests

Struct ImmCapAccessRequests 

pub struct ImmCapAccessRequests<Caps: CapSet> { /* private fields */ }
Tracks what kind of query accesses capability has requested

Implementations

Source

impl<Caps: CapSet> ImmCapAccessRequests<Caps>

pub fn request_component_read<C: Component>(&mut self, world: &mut World)

Mark that component will be immutably accessed

pub fn request_component_write<C: Component<Mutability = Mutable>>( &mut self, world: &mut World, )

Mark that component will be mutably accessed

pub fn request_resource_read<R: Resource>(&mut self, world: &mut World)

Mark that resource will be read during immediate mode

pub fn request_resource_write<R: Resource>(&mut self, world: &mut World)

Mark that resource will be written during immediate mode

pub fn add_on_children_event_listener( &mut self, listener: Box<dyn Fn(&mut ImmEntity<'_, '_, '_, Caps>) + Send + Sync>, )

Add listener that will be called after child entity is created in UI

pub fn requested_components(&self) -> &HashMap<ComponentId, ComponentRequests>

Returns requested component id and their mutability

pub fn requested_resources(&self) -> &HashMap<ComponentId, ResourceRequest>

Returns component_ids for requested resources and their mutability