Module utils

Module utils 

Utility types to simplify implementation

Structs

ImmLocalHashMemoryHelper
Helper tool to store simple hashed state in immediate mode entity.
ImmTypeMap
Wrapper structure around TypeMap for capabilities to store temporary data.

Traits

Mutable
Helper trait to abstract operations over mutable data that could be inside change tracking container like bevy_ecs::prelude::Mut